import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';//importing the libraries

const csvUrl = [
  'https://gist.githubusercontent.com/Tulluripallavi/1b7e05d30a39d5f3d7e01a8678196ecf/raw/340a08b6320c3fd75d7fc76989aa8d8e787d83f3/Iris.csv', // File name
].join('');// connecting to the dataset values.
const parseRow = (d) => {// function for values on X and Y axis
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;
  return d;
};

const width = window.innerWidth;// width of the graph 
const height = window.innerHeight;//height of the graph
const svg = select('body')// for svg graph
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const xValue = (d) => d.petal_length;// for the x and y values in the graph
const yValue = (d) => d.petal_width;
const rxValue = (d) => d.sepal_length;
const ryValue = (d) => d.sepal_width;
const speciesValue = (d) => d.species;

const main = async () => {// For the dots in the graph
  const data = await csv(csvUrl, parseRow);
  const x = xValue((d) => d.petal_width);
  const y = yValue((d) => d.sepal_length);
  const marker = (d) => {
        	switch(d){// for the color in the graph
            case 'setosa':
              return 'orange';
            case 'versicolor':
              return 'purple';
            default:
              return 'pink';
          }
        }
  
  const marks = data.map((d) => ({// for the values in the x and y values in the graph 
          x: xValue((d) => d.petal_width),
          y: yValue((d) => d.sepal_length),
          species: speciesValue(d),
          color: marker(speciesValue(d)),
        	rx: rxValue(d),
          ry: ryValue(d),
                      
        }));
  
  const plot = scatterPlot()// for the height and width of the graph
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.petal_width)
    .yValue((d) => d.sepal_length)
    .margin({
      top: 20,
      right: 10,
      bottom: 100,
      left: 70,
    })
    .radius(5);
  
svg
          .selectAll('circle')// for the dots in the graph
          .data(marks)
          .join('circle')
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry));
  
       //for adding the Y lable 
    svg.append("text")
        .attr("x",-300)
        .attr("y",20)
        .attr("font-size","14px")
        .attr("transform","rotate(-90)")
        .text("Sepal Length")
        
        // for adding the X lable
    svg.append("text")
        .attr("x",500)
        .attr("y",475)
        .attr("font-size","14px")
        .text("Petal Length")

  
  const columns = [// for printing the X and Y values
    'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length',
  ];
  
  let i = 0;//increment of the x and y values
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);
    svg.call(plot);
    i++;
  }, 2000);
};
main();
